Plot Markers (`ligo.skymap.plot.marker`)
========================================

.. autodata:: ligo.skymap.plot.marker.earth

.. automodule:: ligo.skymap.plot.marker
    :members:
    :show-inheritance:
